==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicComboBoxUI__24ListDataHandler.h <==
// public class javax.swing.plaf.basic.BasicComboBoxUI$ListDataHandler

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 668cb67225d48f47 javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler_H_
#define _JC_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_event_ListDataEvent$object;
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$sub_refs	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$refs	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$nonrefs	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$object	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$vmethods	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$vtable	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$vtype	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$method$_init$2bc13d637ee2ba7f(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$object *, struct _jc_javax_swing_plaf_basic_BasicComboBoxUI$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$method$contentsChanged$c5b5afa57c7efdab(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$object *, struct _jc_javax_swing_event_ListDataEvent$object *);
extern void _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$method$intervalAdded$c10548227f018e1d(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$object *, struct _jc_javax_swing_event_ListDataEvent$object *);
extern void _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$method$intervalRemoved$5c70087e83dde061(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$object *, struct _jc_javax_swing_event_ListDataEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$method_info$contentsChanged$c5b5afa57c7efdab;
extern _jc_method _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$method_info$intervalAdded$c10548227f018e1d;
extern _jc_method _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$method_info$intervalRemoved$5c70087e83dde061;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$vmethods {
	void	(*contentsChanged$c5b5afa57c7efdab)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$object *, struct _jc_javax_swing_event_ListDataEvent$object *);
	void	(*intervalAdded$c10548227f018e1d)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$object *, struct _jc_javax_swing_event_ListDataEvent$object *);
	void	(*intervalRemoved$5c70087e83dde061)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$object *, struct _jc_javax_swing_event_ListDataEvent$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$vmethods	javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicComboBoxUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$refs {
    _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$sub_refs	javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$sub_nonrefs	javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$object {
	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$vtype _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicComboBoxUI__24ListDataHandler.h <==
// public class javax.swing.plaf.basic.BasicComboBoxUI$ListDataHandler

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f1583b42b21258 javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler_H_
#define _JC_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_event_ListDataEvent$object;
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$sub_refs	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$refs	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$nonrefs	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$object	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$vmethods	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$vtable	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$vtype	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$method$_init$2bc13d637ee2ba7f(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$object *, struct _jc_javax_swing_plaf_basic_BasicComboBoxUI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$method$contentsChanged$c5b5afa57c7efdab(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$object *, struct _jc_javax_swing_event_ListDataEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$method$intervalAdded$c10548227f018e1d(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$object *, struct _jc_javax_swing_event_ListDataEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$method$intervalRemoved$5c70087e83dde061(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$object *, struct _jc_javax_swing_event_ListDataEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$method_info$contentsChanged$c5b5afa57c7efdab;
extern _jc_method _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$method_info$intervalAdded$c10548227f018e1d;
extern _jc_method _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$method_info$intervalRemoved$5c70087e83dde061;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$vmethods {
	void	(*contentsChanged$c5b5afa57c7efdab)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$object *, struct _jc_javax_swing_event_ListDataEvent$object *) _JC_JCNI_ATTR;
	void	(*intervalAdded$c10548227f018e1d)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$object *, struct _jc_javax_swing_event_ListDataEvent$object *) _JC_JCNI_ATTR;
	void	(*intervalRemoved$5c70087e83dde061)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$object *, struct _jc_javax_swing_event_ListDataEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$vmethods	javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicComboBoxUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$refs {
    _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$sub_refs	javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$sub_nonrefs	javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$object {
	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$vtype _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicComboBoxUI__24ListDataHandler_H_ */
